import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface GlueClassifierConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#name GlueClassifier#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * csv_classifier block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#csv_classifier GlueClassifier#csv_classifier}
     *
     * @stability stable
     */
    readonly csvClassifier?: GlueClassifierCsvClassifier[];
    /**
     * grok_classifier block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#grok_classifier GlueClassifier#grok_classifier}
     *
     * @stability stable
     */
    readonly grokClassifier?: GlueClassifierGrokClassifier[];
    /**
     * json_classifier block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#json_classifier GlueClassifier#json_classifier}
     *
     * @stability stable
     */
    readonly jsonClassifier?: GlueClassifierJsonClassifier[];
    /**
     * xml_classifier block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#xml_classifier GlueClassifier#xml_classifier}
     *
     * @stability stable
     */
    readonly xmlClassifier?: GlueClassifierXmlClassifier[];
}
/**
 * @stability stable
 */
export interface GlueClassifierCsvClassifier {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#allow_single_column GlueClassifier#allow_single_column}.
     *
     * @stability stable
     */
    readonly allowSingleColumn?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#contains_header GlueClassifier#contains_header}.
     *
     * @stability stable
     */
    readonly containsHeader?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#delimiter GlueClassifier#delimiter}.
     *
     * @stability stable
     */
    readonly delimiter?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#disable_value_trimming GlueClassifier#disable_value_trimming}.
     *
     * @stability stable
     */
    readonly disableValueTrimming?: boolean;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#header GlueClassifier#header}.
     *
     * @stability stable
     */
    readonly header?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#quote_symbol GlueClassifier#quote_symbol}.
     *
     * @stability stable
     */
    readonly quoteSymbol?: string;
}
/**
 * @stability stable
 */
export interface GlueClassifierGrokClassifier {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#classification GlueClassifier#classification}.
     *
     * @stability stable
     */
    readonly classification: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#custom_patterns GlueClassifier#custom_patterns}.
     *
     * @stability stable
     */
    readonly customPatterns?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#grok_pattern GlueClassifier#grok_pattern}.
     *
     * @stability stable
     */
    readonly grokPattern: string;
}
/**
 * @stability stable
 */
export interface GlueClassifierJsonClassifier {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#json_path GlueClassifier#json_path}.
     *
     * @stability stable
     */
    readonly jsonPath: string;
}
/**
 * @stability stable
 */
export interface GlueClassifierXmlClassifier {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#classification GlueClassifier#classification}.
     *
     * @stability stable
     */
    readonly classification: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html#row_tag GlueClassifier#row_tag}.
     *
     * @stability stable
     */
    readonly rowTag: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html aws_glue_classifier}.
 *
 * @stability stable
 */
export declare class GlueClassifier extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/aws/r/glue_classifier.html aws_glue_classifier} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: GlueClassifierConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _name;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string;
    private _csvClassifier?;
    /**
     * @stability stable
     */
    get csvClassifier(): GlueClassifierCsvClassifier[];
    /**
     * @stability stable
     */
    set csvClassifier(value: GlueClassifierCsvClassifier[]);
    /**
     * @stability stable
     */
    resetCsvClassifier(): void;
    /**
     * @stability stable
     */
    get csvClassifierInput(): GlueClassifierCsvClassifier[] | undefined;
    private _grokClassifier?;
    /**
     * @stability stable
     */
    get grokClassifier(): GlueClassifierGrokClassifier[];
    /**
     * @stability stable
     */
    set grokClassifier(value: GlueClassifierGrokClassifier[]);
    /**
     * @stability stable
     */
    resetGrokClassifier(): void;
    /**
     * @stability stable
     */
    get grokClassifierInput(): GlueClassifierGrokClassifier[] | undefined;
    private _jsonClassifier?;
    /**
     * @stability stable
     */
    get jsonClassifier(): GlueClassifierJsonClassifier[];
    /**
     * @stability stable
     */
    set jsonClassifier(value: GlueClassifierJsonClassifier[]);
    /**
     * @stability stable
     */
    resetJsonClassifier(): void;
    /**
     * @stability stable
     */
    get jsonClassifierInput(): GlueClassifierJsonClassifier[] | undefined;
    private _xmlClassifier?;
    /**
     * @stability stable
     */
    get xmlClassifier(): GlueClassifierXmlClassifier[];
    /**
     * @stability stable
     */
    set xmlClassifier(value: GlueClassifierXmlClassifier[]);
    /**
     * @stability stable
     */
    resetXmlClassifier(): void;
    /**
     * @stability stable
     */
    get xmlClassifierInput(): GlueClassifierXmlClassifier[] | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
